export default defineNuxtConfig({
  // Global page headers: https://go.nuxtjs.dev/config-head
  app: {
    head: {
      title: 'Jugofuturistični manifest',
      meta: [
        { charset: 'utf-8' },
        { name: 'viewport', content: 'width=device-width, initial-scale=1' },
        { hid: 'description', name: 'description', content: '' },
        { name: 'format-detection', content: 'telephone=no' }
      ],
      link: [
        { rel: 'icon', type: 'image/x-icon', href: '/favicon.ico' },
        { rel: 'stylesheet', type: 'text/css', href: '/css/fonti.css' }
      ]
    }
  },
  imports: {
    dirs: ['stores']
  },
  modules: [
    ['@pinia/nuxt', { autoImports: ['defineStore', 'acceptHMRUpdate']}],
    '@nuxtjs/i18n'
    //'nuxt-proxy'
  ],
  proxy: {
    options: {
      target: process.env.BASE_URL,
      changeOrigin: true,
      pathFilter:
        process.env.FILE_PATH
    }
  },
  runtimeConfig: {
    public: {
      baseUrl: process.env.BASE_URL,
      jsonapiPath: process.env.JSONAPI_PATH,
      etherpadUrl: process.env.ETHERPAD_URL,
      etherpadPrefix: process.env.ETHERPAD_PREFIX
    }
  },
  hooks: {
    'pages:extend' (pages) {
      pages.push({
        name: 'pojem_poglej',
        path: '/manifest/:naslov',
        file: '~/pages/manifest/pojem.vue'
      }, {
        name: 'pojem_uredi',
        path: '/manifest/:naslov/uredi/:guid',
        file: '~/pages/manifest/pojem.vue'
      }, {
        name: 'pojem_dodaj',
        path: '/manifest/dodaj/:guid',
        file: '~/pages/manifest/dodaj.vue'
      })
    }
  },
  i18n: {
    locales: [{
      code: 'sl',
      file: 'sl.json'
    }, {
      code: 'en',
      file: 'en.json'
    }, {
      code: 'hr',
      file: 'hr.json'
    }],
    langDir: 'lang',
    defaultLocale: 'sl',
    fallbackLocale: 'sl'
  }
})
